# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tool_exec_environment_variables_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem,
)

AgentsSearchResponseAgentsItemToolExecEnvironmentVariables = typing.Union[
    typing.List[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem], typing.Optional[typing.Any]
]



# This file was auto-generated by Fern from our API Definition.

from .letta_streaming_response import LettaStreamingResponse
from .message_update_content import MessageUpdateContent

__all__ = ["LettaStreamingResponse", "MessageUpdateContent"]



# This file was auto-generated by Fern from our API Definition.

import typing
from .response_format_text import ResponseFormatText
from .response_format_json_object import ResponseFormatJsonObject
from .response_format_json_schema import ResponseFormatJsonSchema

CompletionCreateParamsNonStreamingResponseFormat = typing.Union[
    ResponseFormatText, ResponseFormatJsonObject, ResponseFormatJsonSchema
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[
            TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem
        ]
    ],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_endpoint_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem]
    ],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing

AgentsSearchResponseAgentsItemToolsItemToolType = typing.Union[
    typing.Literal[
        "custom", "letta_core", "letta_memory_core", "letta_multi_agent_core", "external_composio", "external_langchain"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
)

AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_handle_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem]
    ],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_from_template_response_agents_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_created_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt,
)
from .templates_create_agents_from_template_response_agents_item_updated_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules,
)
from .templates_create_agents_from_template_response_agents_item_message_ids import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds,
)
from .templates_create_agents_from_template_response_agents_item_agent_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType,
)
from .templates_create_agents_from_template_response_agents_item_llm_config import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig,
)
from .templates_create_agents_from_template_response_agents_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_metadata import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata,
)
from .templates_create_agents_from_template_response_agents_item_memory import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory,
)
from .templates_create_agents_from_template_response_agents_item_tools_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables,
)
from .templates_create_agents_from_template_response_agents_item_project_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId,
)
from .templates_create_agents_from_template_response_agents_item_template_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId,
)
from .templates_create_agents_from_template_response_agents_item_base_template_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItem(UncheckedBaseModel):
    created_by_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById] = None
    last_updated_by_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById] = None
    created_at: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt] = None
    updated_at: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt] = None
    id: str
    name: str
    tool_rules: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules] = None
    message_ids: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds] = None
    system: str
    agent_type: TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType
    llm_config: TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig
    embedding_config: TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig
    organization_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId] = None
    description: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription] = None
    metadata: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata] = None
    memory: TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory
    tools: typing.List[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem]
    sources: typing.List[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem]
    tags: typing.List[str]
    tool_exec_environment_variables: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables
    ] = None
    project_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId] = None
    template_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId] = None
    base_template_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .chat_completion_user_message_param_content_item import ChatCompletionUserMessageParamContentItem

ChatCompletionUserMessageParamContent = typing.Union[str, typing.List[ChatCompletionUserMessageParamContentItem]]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import datetime as dt
import typing
from .user_message_content import UserMessageContent
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class UserMessage(UncheckedBaseModel):
    """
    A message sent by the user. Never streamed back on a response, only used for cursor pagination.

    Attributes:
        content (Union[str, List[MessageContentUnion]]): The message content sent by the user (can be a string or an array of content parts)
        id (str): The ID of the message
        date (datetime): The date the message was created in ISO format
    """

    id: str
    date: dt.datetime
    message_type: typing.Literal["user_message"] = "user_message"
    content: UserMessageContent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .agents_search_request_search_item import AgentsSearchRequestSearchItem
from .agents_search_request_search_item_field import AgentsSearchRequestSearchItemField
from .agents_search_request_search_item_one import AgentsSearchRequestSearchItemOne
from .agents_search_request_search_item_one_operator import AgentsSearchRequestSearchItemOneOperator
from .agents_search_request_search_item_zero import AgentsSearchRequestSearchItemZero
from .agents_search_response import AgentsSearchResponse
from .agents_search_response_agents_item import AgentsSearchResponseAgentsItem
from .agents_search_response_agents_item_agent_type import AgentsSearchResponseAgentsItemAgentType
from .agents_search_response_agents_item_base_template_id import AgentsSearchResponseAgentsItemBaseTemplateId
from .agents_search_response_agents_item_base_template_id_item import AgentsSearchResponseAgentsItemBaseTemplateIdItem
from .agents_search_response_agents_item_created_at import AgentsSearchResponseAgentsItemCreatedAt
from .agents_search_response_agents_item_created_at_item import AgentsSearchResponseAgentsItemCreatedAtItem
from .agents_search_response_agents_item_created_by_id import AgentsSearchResponseAgentsItemCreatedById
from .agents_search_response_agents_item_created_by_id_item import AgentsSearchResponseAgentsItemCreatedByIdItem
from .agents_search_response_agents_item_description import AgentsSearchResponseAgentsItemDescription
from .agents_search_response_agents_item_description_item import AgentsSearchResponseAgentsItemDescriptionItem
from .agents_search_response_agents_item_embedding_config import AgentsSearchResponseAgentsItemEmbeddingConfig
from .agents_search_response_agents_item_embedding_config_azure_deployment import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment,
)
from .agents_search_response_agents_item_embedding_config_azure_deployment_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
)
from .agents_search_response_agents_item_embedding_config_azure_endpoint import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint,
)
from .agents_search_response_agents_item_embedding_config_azure_endpoint_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem,
)
from .agents_search_response_agents_item_embedding_config_azure_version import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion,
)
from .agents_search_response_agents_item_embedding_config_azure_version_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem,
)
from .agents_search_response_agents_item_embedding_config_embedding_chunk_size import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
)
from .agents_search_response_agents_item_embedding_config_embedding_chunk_size_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
)
from .agents_search_response_agents_item_embedding_config_embedding_endpoint import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
)
from .agents_search_response_agents_item_embedding_config_embedding_endpoint_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
)
from .agents_search_response_agents_item_embedding_config_embedding_endpoint_type import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
)
from .agents_search_response_agents_item_embedding_config_handle import (
    AgentsSearchResponseAgentsItemEmbeddingConfigHandle,
)
from .agents_search_response_agents_item_embedding_config_handle_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem,
)
from .agents_search_response_agents_item_last_updated_by_id import AgentsSearchResponseAgentsItemLastUpdatedById
from .agents_search_response_agents_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_llm_config import AgentsSearchResponseAgentsItemLlmConfig
from .agents_search_response_agents_item_llm_config_handle import AgentsSearchResponseAgentsItemLlmConfigHandle
from .agents_search_response_agents_item_llm_config_handle_item import AgentsSearchResponseAgentsItemLlmConfigHandleItem
from .agents_search_response_agents_item_llm_config_model_endpoint import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpoint,
)
from .agents_search_response_agents_item_llm_config_model_endpoint_item import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem,
)
from .agents_search_response_agents_item_llm_config_model_endpoint_type import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointType,
)
from .agents_search_response_agents_item_llm_config_model_wrapper import (
    AgentsSearchResponseAgentsItemLlmConfigModelWrapper,
)
from .agents_search_response_agents_item_llm_config_model_wrapper_item import (
    AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem,
)
from .agents_search_response_agents_item_llm_config_put_inner_thoughts_in_kwargs import (
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
)
from .agents_search_response_agents_item_llm_config_put_inner_thoughts_in_kwargs_item import (
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
)
from .agents_search_response_agents_item_llm_config_temperature import (
    AgentsSearchResponseAgentsItemLlmConfigTemperature,
)
from .agents_search_response_agents_item_memory import AgentsSearchResponseAgentsItemMemory
from .agents_search_response_agents_item_memory_blocks_item import AgentsSearchResponseAgentsItemMemoryBlocksItem
from .agents_search_response_agents_item_memory_blocks_item_created_by_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById,
)
from .agents_search_response_agents_item_memory_blocks_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
)
from .agents_search_response_agents_item_memory_blocks_item_description import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescription,
)
from .agents_search_response_agents_item_memory_blocks_item_description_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem,
)
from .agents_search_response_agents_item_memory_blocks_item_id import AgentsSearchResponseAgentsItemMemoryBlocksItemId
from .agents_search_response_agents_item_memory_blocks_item_is_template import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate,
)
from .agents_search_response_agents_item_memory_blocks_item_label import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabel,
)
from .agents_search_response_agents_item_memory_blocks_item_label_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem,
)
from .agents_search_response_agents_item_memory_blocks_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById,
)
from .agents_search_response_agents_item_memory_blocks_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_memory_blocks_item_limit import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLimit,
)
from .agents_search_response_agents_item_memory_blocks_item_metadata import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata,
)
from .agents_search_response_agents_item_memory_blocks_item_metadata_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem,
)
from .agents_search_response_agents_item_memory_blocks_item_name import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemName,
)
from .agents_search_response_agents_item_memory_blocks_item_name_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem,
)
from .agents_search_response_agents_item_memory_blocks_item_organization_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId,
)
from .agents_search_response_agents_item_memory_blocks_item_organization_id_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
)
from .agents_search_response_agents_item_memory_prompt_template import (
    AgentsSearchResponseAgentsItemMemoryPromptTemplate,
)
from .agents_search_response_agents_item_message_ids import AgentsSearchResponseAgentsItemMessageIds
from .agents_search_response_agents_item_message_ids_item import AgentsSearchResponseAgentsItemMessageIdsItem
from .agents_search_response_agents_item_metadata import AgentsSearchResponseAgentsItemMetadata
from .agents_search_response_agents_item_metadata_item import AgentsSearchResponseAgentsItemMetadataItem
from .agents_search_response_agents_item_organization_id import AgentsSearchResponseAgentsItemOrganizationId
from .agents_search_response_agents_item_organization_id_item import AgentsSearchResponseAgentsItemOrganizationIdItem
from .agents_search_response_agents_item_project_id import AgentsSearchResponseAgentsItemProjectId
from .agents_search_response_agents_item_project_id_item import AgentsSearchResponseAgentsItemProjectIdItem
from .agents_search_response_agents_item_sources_item import AgentsSearchResponseAgentsItemSourcesItem
from .agents_search_response_agents_item_sources_item_created_at import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedAt,
)
from .agents_search_response_agents_item_sources_item_created_at_item import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem,
)
from .agents_search_response_agents_item_sources_item_created_by_id import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedById,
)
from .agents_search_response_agents_item_sources_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem,
)
from .agents_search_response_agents_item_sources_item_description import (
    AgentsSearchResponseAgentsItemSourcesItemDescription,
)
from .agents_search_response_agents_item_sources_item_description_item import (
    AgentsSearchResponseAgentsItemSourcesItemDescriptionItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_deployment import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_deployment_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_endpoint_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_version import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_version_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_chunk_size_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
from .agents_search_response_agents_item_sources_item_embedding_config_handle import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .agents_search_response_agents_item_sources_item_embedding_config_handle_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
)
from .agents_search_response_agents_item_sources_item_id import AgentsSearchResponseAgentsItemSourcesItemId
from .agents_search_response_agents_item_sources_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById,
)
from .agents_search_response_agents_item_sources_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_sources_item_metadata import AgentsSearchResponseAgentsItemSourcesItemMetadata
from .agents_search_response_agents_item_sources_item_metadata_item import (
    AgentsSearchResponseAgentsItemSourcesItemMetadataItem,
)
from .agents_search_response_agents_item_sources_item_organization_id import (
    AgentsSearchResponseAgentsItemSourcesItemOrganizationId,
)
from .agents_search_response_agents_item_sources_item_organization_id_item import (
    AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem,
)
from .agents_search_response_agents_item_sources_item_updated_at import (
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAt,
)
from .agents_search_response_agents_item_sources_item_updated_at_item import (
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem,
)
from .agents_search_response_agents_item_template_id import AgentsSearchResponseAgentsItemTemplateId
from .agents_search_response_agents_item_template_id_item import AgentsSearchResponseAgentsItemTemplateIdItem
from .agents_search_response_agents_item_tool_exec_environment_variables import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariables,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_at import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_at_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_description import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_description_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_organization_id_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_updated_at_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
)
from .agents_search_response_agents_item_tool_rules import AgentsSearchResponseAgentsItemToolRules
from .agents_search_response_agents_item_tool_rules_item import AgentsSearchResponseAgentsItemToolRulesItem
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping_default_child import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
)
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping_default_child_item import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
)
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping_require_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping_type import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType,
)
from .agents_search_response_agents_item_tool_rules_item_children import (
    AgentsSearchResponseAgentsItemToolRulesItemChildren,
)
from .agents_search_response_agents_item_tool_rules_item_children_type import (
    AgentsSearchResponseAgentsItemToolRulesItemChildrenType,
)
from .agents_search_response_agents_item_tool_rules_item_item import AgentsSearchResponseAgentsItemToolRulesItemItem
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping_default_child import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping_default_child_item import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping_require_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping_type import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType,
)
from .agents_search_response_agents_item_tool_rules_item_item_children import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildren,
)
from .agents_search_response_agents_item_tool_rules_item_item_children_type import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType,
)
from .agents_search_response_agents_item_tool_rules_item_item_one import (
    AgentsSearchResponseAgentsItemToolRulesItemItemOne,
)
from .agents_search_response_agents_item_tool_rules_item_item_one_type import (
    AgentsSearchResponseAgentsItemToolRulesItemItemOneType,
)
from .agents_search_response_agents_item_tool_rules_item_item_two import (
    AgentsSearchResponseAgentsItemToolRulesItemItemTwo,
)
from .agents_search_response_agents_item_tool_rules_item_item_two_type import (
    AgentsSearchResponseAgentsItemToolRulesItemItemTwoType,
)
from .agents_search_response_agents_item_tool_rules_item_one import AgentsSearchResponseAgentsItemToolRulesItemOne
from .agents_search_response_agents_item_tool_rules_item_one_type import (
    AgentsSearchResponseAgentsItemToolRulesItemOneType,
)
from .agents_search_response_agents_item_tool_rules_item_two import AgentsSearchResponseAgentsItemToolRulesItemTwo
from .agents_search_response_agents_item_tool_rules_item_two_type import (
    AgentsSearchResponseAgentsItemToolRulesItemTwoType,
)
from .agents_search_response_agents_item_tools_item import AgentsSearchResponseAgentsItemToolsItem
from .agents_search_response_agents_item_tools_item_created_by_id import (
    AgentsSearchResponseAgentsItemToolsItemCreatedById,
)
from .agents_search_response_agents_item_tools_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem,
)
from .agents_search_response_agents_item_tools_item_description import (
    AgentsSearchResponseAgentsItemToolsItemDescription,
)
from .agents_search_response_agents_item_tools_item_description_item import (
    AgentsSearchResponseAgentsItemToolsItemDescriptionItem,
)
from .agents_search_response_agents_item_tools_item_json_schema import AgentsSearchResponseAgentsItemToolsItemJsonSchema
from .agents_search_response_agents_item_tools_item_json_schema_item import (
    AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem,
)
from .agents_search_response_agents_item_tools_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedById,
)
from .agents_search_response_agents_item_tools_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_tools_item_name import AgentsSearchResponseAgentsItemToolsItemName
from .agents_search_response_agents_item_tools_item_name_item import AgentsSearchResponseAgentsItemToolsItemNameItem
from .agents_search_response_agents_item_tools_item_organization_id import (
    AgentsSearchResponseAgentsItemToolsItemOrganizationId,
)
from .agents_search_response_agents_item_tools_item_organization_id_item import (
    AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem,
)
from .agents_search_response_agents_item_tools_item_source_code import AgentsSearchResponseAgentsItemToolsItemSourceCode
from .agents_search_response_agents_item_tools_item_source_code_item import (
    AgentsSearchResponseAgentsItemToolsItemSourceCodeItem,
)
from .agents_search_response_agents_item_tools_item_source_type import AgentsSearchResponseAgentsItemToolsItemSourceType
from .agents_search_response_agents_item_tools_item_source_type_item import (
    AgentsSearchResponseAgentsItemToolsItemSourceTypeItem,
)
from .agents_search_response_agents_item_tools_item_tool_type import AgentsSearchResponseAgentsItemToolsItemToolType
from .agents_search_response_agents_item_updated_at import AgentsSearchResponseAgentsItemUpdatedAt
from .agents_search_response_agents_item_updated_at_item import AgentsSearchResponseAgentsItemUpdatedAtItem
from .create_agent_request_tool_rules_item import CreateAgentRequestToolRulesItem
from .update_agent_tool_rules_item import UpdateAgentToolRulesItem

__all__ = [
    "AgentsSearchRequestSearchItem",
    "AgentsSearchRequestSearchItemField",
    "AgentsSearchRequestSearchItemOne",
    "AgentsSearchRequestSearchItemOneOperator",
    "AgentsSearchRequestSearchItemZero",
    "AgentsSearchResponse",
    "AgentsSearchResponseAgentsItem",
    "AgentsSearchResponseAgentsItemAgentType",
    "AgentsSearchResponseAgentsItemBaseTemplateId",
    "AgentsSearchResponseAgentsItemBaseTemplateIdItem",
    "AgentsSearchResponseAgentsItemCreatedAt",
    "AgentsSearchResponseAgentsItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemCreatedById",
    "AgentsSearchResponseAgentsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemDescription",
    "AgentsSearchResponseAgentsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemLlmConfig",
    "AgentsSearchResponseAgentsItemLlmConfigHandle",
    "AgentsSearchResponseAgentsItemLlmConfigHandleItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpoint",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointType",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapper",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "AgentsSearchResponseAgentsItemLlmConfigTemperature",
    "AgentsSearchResponseAgentsItemMemory",
    "AgentsSearchResponseAgentsItemMemoryBlocksItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescription",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabel",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLimit",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemName",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemMemoryPromptTemplate",
    "AgentsSearchResponseAgentsItemMessageIds",
    "AgentsSearchResponseAgentsItemMessageIdsItem",
    "AgentsSearchResponseAgentsItemMetadata",
    "AgentsSearchResponseAgentsItemMetadataItem",
    "AgentsSearchResponseAgentsItemOrganizationId",
    "AgentsSearchResponseAgentsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemProjectId",
    "AgentsSearchResponseAgentsItemProjectIdItem",
    "AgentsSearchResponseAgentsItemSourcesItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedById",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemDescription",
    "AgentsSearchResponseAgentsItemSourcesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemSourcesItemId",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemMetadata",
    "AgentsSearchResponseAgentsItemSourcesItemMetadataItem",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationId",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemTemplateId",
    "AgentsSearchResponseAgentsItemTemplateIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariables",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemToolRules",
    "AgentsSearchResponseAgentsItemToolRulesItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwoType",
    "AgentsSearchResponseAgentsItemToolRulesItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemTwoType",
    "AgentsSearchResponseAgentsItemToolsItem",
    "AgentsSearchResponseAgentsItemToolsItemCreatedById",
    "AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemDescription",
    "AgentsSearchResponseAgentsItemToolsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchema",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemName",
    "AgentsSearchResponseAgentsItemToolsItemNameItem",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceCode",
    "AgentsSearchResponseAgentsItemToolsItemSourceCodeItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceType",
    "AgentsSearchResponseAgentsItemToolsItemSourceTypeItem",
    "AgentsSearchResponseAgentsItemToolsItemToolType",
    "AgentsSearchResponseAgentsItemUpdatedAt",
    "AgentsSearchResponseAgentsItemUpdatedAtItem",
    "CreateAgentRequestToolRulesItem",
    "UpdateAgentToolRulesItem",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ToolCreate(UncheckedBaseModel):
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the tool.
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Metadata tags.
    """

    source_code: str = pydantic.Field()
    """
    The source code of the function.
    """

    source_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The source type of the function.
    """

    json_schema: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    The JSON schema of the function (auto-generated from source_code if not provided)
    """

    return_char_limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum number of characters in the response.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tools_item_description_item import (
    AgentsSearchResponseAgentsItemToolsItemDescriptionItem,
)

AgentsSearchResponseAgentsItemToolsItemDescription = typing.Union[
    str, typing.Optional[str], typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolsItemDescriptionItem]]
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_at import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_description import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem(UncheckedBaseModel):
    created_by_id: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById] = None
    last_updated_by_id: typing.Optional[
        AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById
    ] = None
    created_at: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt] = None
    updated_at: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt] = None
    id: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId] = None
    key: str
    value: str
    description: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription] = None
    organization_id: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId] = (
        None
    )
    agent_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



import inspect
import typing
from textwrap import dedent

from .base_client import AsyncLettaBase, LettaBase
from .core.request_options import RequestOptions
from .tools.client import ToolsClient as ToolsClientBase
from .types.tool import Tool

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class Letta(LettaBase):

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.tools = ToolsClient(client_wrapper=self._client_wrapper)


class AsyncLetta(AsyncLettaBase):

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.tools = ToolsClient(client_wrapper=self._client_wrapper)


class ToolsClient(ToolsClientBase):

    def create_from_function(
        self,
        *,
        func: typing.Callable,
        description: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        source_type: typing.Optional[str] = OMIT,
        json_schema: typing.Optional[
            typing.Dict[str, typing.Optional[typing.Any]]
        ] = OMIT,
        return_char_limit: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Tool:
        source_code = dedent(inspect.getsource(func))
        return self.create(
            source_code=source_code,
            description=description,
            tags=tags,
            source_type=source_type,
            json_schema=json_schema,
            return_char_limit=return_char_limit,
            request_options=request_options,
        )

    def upsert_from_function(
        self,
        *,
        func: typing.Callable,
        description: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        source_type: typing.Optional[str] = OMIT,
        json_schema: typing.Optional[
            typing.Dict[str, typing.Optional[typing.Any]]
        ] = OMIT,
        return_char_limit: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Tool:
        source_code = dedent(inspect.getsource(func))
        return self.upsert(
            source_code=source_code,
            description=description,
            tags=tags,
            source_type=source_type,
            json_schema=json_schema,
            return_char_limit=return_char_limit,
            request_options=request_options,
        )



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_metadata_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata = typing.Union[
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_llm_config_put_inner_thoughts_in_kwargs_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs = typing.Union[
    bool,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem]
    ],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_llm_config_model_wrapper_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ActionModel,
    ActionParametersModel,
    ActionResponseModel,
    AgentEnvironmentVariable,
    AgentState,
    AgentStateToolRulesItem,
    AgentType,
    AppAuthScheme,
    AppAuthSchemeAuthMode,
    AppModel,
    AssistantMessage,
    AssistantMessageContent,
    Audio,
    AuthRequest,
    AuthResponse,
    AuthSchemeField,
    Block,
    BlockUpdate,
    ChatCompletionAssistantMessageParam,
    ChatCompletionAssistantMessageParamContent,
    ChatCompletionAssistantMessageParamContentItem,
    ChatCompletionAudioParam,
    ChatCompletionAudioParamFormat,
    ChatCompletionAudioParamVoice,
    ChatCompletionContentPartImageParam,
    ChatCompletionContentPartInputAudioParam,
    ChatCompletionContentPartRefusalParam,
    ChatCompletionContentPartTextParam,
    ChatCompletionDeveloperMessageParam,
    ChatCompletionDeveloperMessageParamContent,
    ChatCompletionFunctionCallOptionParam,
    ChatCompletionFunctionMessageParam,
    ChatCompletionMessageToolCallInput,
    ChatCompletionMessageToolCallOutput,
    ChatCompletionMessageToolCallParam,
    ChatCompletionNamedToolChoiceParam,
    ChatCompletionPredictionContentParam,
    ChatCompletionPredictionContentParamContent,
    ChatCompletionStreamOptionsParam,
    ChatCompletionSystemMessageParam,
    ChatCompletionSystemMessageParamContent,
    ChatCompletionToolMessageParam,
    ChatCompletionToolMessageParamContent,
    ChatCompletionToolParam,
    ChatCompletionUserMessageParam,
    ChatCompletionUserMessageParamContent,
    ChatCompletionUserMessageParamContentItem,
    ChildToolRule,
    CompletionCreateParamsNonStreaming,
    CompletionCreateParamsNonStreamingFunctionCall,
    CompletionCreateParamsNonStreamingMessagesItem,
    CompletionCreateParamsNonStreamingModalitiesItem,
    CompletionCreateParamsNonStreamingModel,
    CompletionCreateParamsNonStreamingReasoningEffort,
    CompletionCreateParamsNonStreamingResponseFormat,
    CompletionCreateParamsNonStreamingServiceTier,
    CompletionCreateParamsNonStreamingStop,
    CompletionCreateParamsNonStreamingToolChoice,
    CompletionCreateParamsStreaming,
    CompletionCreateParamsStreamingFunctionCall,
    CompletionCreateParamsStreamingMessagesItem,
    CompletionCreateParamsStreamingModalitiesItem,
    CompletionCreateParamsStreamingModel,
    CompletionCreateParamsStreamingReasoningEffort,
    CompletionCreateParamsStreamingResponseFormat,
    CompletionCreateParamsStreamingServiceTier,
    CompletionCreateParamsStreamingStop,
    CompletionCreateParamsStreamingToolChoice,
    ConditionalToolRule,
    ConflictErrorBody,
    ContextWindowOverview,
    CreateBlock,
    E2BSandboxConfig,
    EmbeddingConfig,
    EmbeddingConfigEmbeddingEndpointType,
    FileMetadata,
    FunctionCall,
    FunctionDefinitionInput,
    FunctionDefinitionOutput,
    FunctionOutput,
    FunctionTool,
    Health,
    HttpValidationError,
    ImageUrl,
    ImageUrlDetail,
    InitToolRule,
    InputAudio,
    InputAudioFormat,
    InternalServerErrorBody,
    Job,
    JobStatus,
    JobType,
    JsonSchema,
    LettaMessageUnion,
    LettaRequest,
    LettaRequestConfig,
    LettaResponse,
    LettaUsageStatistics,
    LlmConfig,
    LlmConfigModelEndpointType,
    LocalSandboxConfig,
    Memory,
    Message,
    MessageCreate,
    MessageCreateContent,
    MessageCreateRole,
    MessageRole,
    NotFoundErrorBody,
    NotFoundErrorBodyMessage,
    OpenaiTypesChatChatCompletionMessageToolCallFunction,
    OpenaiTypesChatChatCompletionMessageToolCallParamFunction,
    OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction,
    OpenaiTypesChatCompletionCreateParamsFunction,
    Organization,
    OrganizationCreate,
    Passage,
    PipRequirement,
    Provider,
    ReasoningMessage,
    ResponseFormatJsonObject,
    ResponseFormatJsonSchema,
    ResponseFormatText,
    Run,
    SandboxConfig,
    SandboxConfigCreate,
    SandboxConfigCreateConfig,
    SandboxConfigUpdate,
    SandboxConfigUpdateConfig,
    SandboxEnvironmentVariable,
    SandboxEnvironmentVariableCreate,
    SandboxEnvironmentVariableUpdate,
    SandboxType,
    Source,
    Step,
    SystemMessage,
    SystemMessageContent,
    TerminalToolRule,
    TextContent,
    Tool,
    ToolCall,
    ToolCallDelta,
    ToolCallMessage,
    ToolCallMessageToolCall,
    ToolCreate,
    ToolReturnMessage,
    ToolReturnMessageStatus,
    ToolType,
    UsageStatistics,
    User,
    UserCreate,
    UserMessage,
    UserMessageContent,
    UserUpdate,
    ValidationError,
    ValidationErrorLocItem,
)
from .errors import ConflictError, InternalServerError, NotFoundError, UnprocessableEntityError
from . import agents, blocks, health, jobs, models, providers, runs, sources, steps, tag, templates, tools
from .agents import (
    AgentsSearchRequestSearchItem,
    AgentsSearchRequestSearchItemField,
    AgentsSearchRequestSearchItemOne,
    AgentsSearchRequestSearchItemOneOperator,
    AgentsSearchRequestSearchItemZero,
    AgentsSearchResponse,
    AgentsSearchResponseAgentsItem,
    AgentsSearchResponseAgentsItemAgentType,
    AgentsSearchResponseAgentsItemBaseTemplateId,
    AgentsSearchResponseAgentsItemBaseTemplateIdItem,
    AgentsSearchResponseAgentsItemCreatedAt,
    AgentsSearchResponseAgentsItemCreatedAtItem,
    AgentsSearchResponseAgentsItemCreatedById,
    AgentsSearchResponseAgentsItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemDescription,
    AgentsSearchResponseAgentsItemDescriptionItem,
    AgentsSearchResponseAgentsItemEmbeddingConfig,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    AgentsSearchResponseAgentsItemEmbeddingConfigHandle,
    AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem,
    AgentsSearchResponseAgentsItemLastUpdatedById,
    AgentsSearchResponseAgentsItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemLlmConfig,
    AgentsSearchResponseAgentsItemLlmConfigHandle,
    AgentsSearchResponseAgentsItemLlmConfigHandleItem,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpoint,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointType,
    AgentsSearchResponseAgentsItemLlmConfigModelWrapper,
    AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem,
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    AgentsSearchResponseAgentsItemLlmConfigTemperature,
    AgentsSearchResponseAgentsItemMemory,
    AgentsSearchResponseAgentsItemMemoryBlocksItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById,
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescription,
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemId,
    AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabel,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLimit,
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata,
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemName,
    AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId,
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemMemoryPromptTemplate,
    AgentsSearchResponseAgentsItemMessageIds,
    AgentsSearchResponseAgentsItemMessageIdsItem,
    AgentsSearchResponseAgentsItemMetadata,
    AgentsSearchResponseAgentsItemMetadataItem,
    AgentsSearchResponseAgentsItemOrganizationId,
    AgentsSearchResponseAgentsItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemProjectId,
    AgentsSearchResponseAgentsItemProjectIdItem,
    AgentsSearchResponseAgentsItemSourcesItem,
    AgentsSearchResponseAgentsItemSourcesItemCreatedAt,
    AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem,
    AgentsSearchResponseAgentsItemSourcesItemCreatedById,
    AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemSourcesItemDescription,
    AgentsSearchResponseAgentsItemSourcesItemDescriptionItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    AgentsSearchResponseAgentsItemSourcesItemId,
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById,
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemSourcesItemMetadata,
    AgentsSearchResponseAgentsItemSourcesItemMetadataItem,
    AgentsSearchResponseAgentsItemSourcesItemOrganizationId,
    AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAt,
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem,
    AgentsSearchResponseAgentsItemTemplateId,
    AgentsSearchResponseAgentsItemTemplateIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariables,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    AgentsSearchResponseAgentsItemToolRules,
    AgentsSearchResponseAgentsItemToolRulesItem,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType,
    AgentsSearchResponseAgentsItemToolRulesItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemChildrenType,
    AgentsSearchResponseAgentsItemToolRulesItemItem,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType,
    AgentsSearchResponseAgentsItemToolRulesItemItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemItemOneType,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwoType,
    AgentsSearchResponseAgentsItemToolRulesItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemOneType,
    AgentsSearchResponseAgentsItemToolRulesItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemTwoType,
    AgentsSearchResponseAgentsItemToolsItem,
    AgentsSearchResponseAgentsItemToolsItemCreatedById,
    AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemToolsItemDescription,
    AgentsSearchResponseAgentsItemToolsItemDescriptionItem,
    AgentsSearchResponseAgentsItemToolsItemJsonSchema,
    AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem,
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedById,
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemToolsItemName,
    AgentsSearchResponseAgentsItemToolsItemNameItem,
    AgentsSearchResponseAgentsItemToolsItemOrganizationId,
    AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemToolsItemSourceCode,
    AgentsSearchResponseAgentsItemToolsItemSourceCodeItem,
    AgentsSearchResponseAgentsItemToolsItemSourceType,
    AgentsSearchResponseAgentsItemToolsItemSourceTypeItem,
    AgentsSearchResponseAgentsItemToolsItemToolType,
    AgentsSearchResponseAgentsItemUpdatedAt,
    AgentsSearchResponseAgentsItemUpdatedAtItem,
    CreateAgentRequestToolRulesItem,
    UpdateAgentToolRulesItem,
)
from .client import AsyncLetta, Letta
from .environment import LettaEnvironment
from .templates import (
    TemplatesCreateAgentsFromTemplateResponse,
    TemplatesCreateAgentsFromTemplateResponseAgentsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabelItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemNameItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryPromptTemplate,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildren,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildrenType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildrenType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOneType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOne,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOneType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwo,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwoType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCodeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAtItem,
)
from .version import __version__

__all__ = [
    "ActionModel",
    "ActionParametersModel",
    "ActionResponseModel",
    "AgentEnvironmentVariable",
    "AgentState",
    "AgentStateToolRulesItem",
    "AgentType",
    "AgentsSearchRequestSearchItem",
    "AgentsSearchRequestSearchItemField",
    "AgentsSearchRequestSearchItemOne",
    "AgentsSearchRequestSearchItemOneOperator",
    "AgentsSearchRequestSearchItemZero",
    "AgentsSearchResponse",
    "AgentsSearchResponseAgentsItem",
    "AgentsSearchResponseAgentsItemAgentType",
    "AgentsSearchResponseAgentsItemBaseTemplateId",
    "AgentsSearchResponseAgentsItemBaseTemplateIdItem",
    "AgentsSearchResponseAgentsItemCreatedAt",
    "AgentsSearchResponseAgentsItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemCreatedById",
    "AgentsSearchResponseAgentsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemDescription",
    "AgentsSearchResponseAgentsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemLlmConfig",
    "AgentsSearchResponseAgentsItemLlmConfigHandle",
    "AgentsSearchResponseAgentsItemLlmConfigHandleItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpoint",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointType",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapper",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "AgentsSearchResponseAgentsItemLlmConfigTemperature",
    "AgentsSearchResponseAgentsItemMemory",
    "AgentsSearchResponseAgentsItemMemoryBlocksItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescription",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabel",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLimit",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemName",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemMemoryPromptTemplate",
    "AgentsSearchResponseAgentsItemMessageIds",
    "AgentsSearchResponseAgentsItemMessageIdsItem",
    "AgentsSearchResponseAgentsItemMetadata",
    "AgentsSearchResponseAgentsItemMetadataItem",
    "AgentsSearchResponseAgentsItemOrganizationId",
    "AgentsSearchResponseAgentsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemProjectId",
    "AgentsSearchResponseAgentsItemProjectIdItem",
    "AgentsSearchResponseAgentsItemSourcesItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedById",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemDescription",
    "AgentsSearchResponseAgentsItemSourcesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemSourcesItemId",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemMetadata",
    "AgentsSearchResponseAgentsItemSourcesItemMetadataItem",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationId",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemTemplateId",
    "AgentsSearchResponseAgentsItemTemplateIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariables",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemToolRules",
    "AgentsSearchResponseAgentsItemToolRulesItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwoType",
    "AgentsSearchResponseAgentsItemToolRulesItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemTwoType",
    "AgentsSearchResponseAgentsItemToolsItem",
    "AgentsSearchResponseAgentsItemToolsItemCreatedById",
    "AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemDescription",
    "AgentsSearchResponseAgentsItemToolsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchema",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemName",
    "AgentsSearchResponseAgentsItemToolsItemNameItem",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceCode",
    "AgentsSearchResponseAgentsItemToolsItemSourceCodeItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceType",
    "AgentsSearchResponseAgentsItemToolsItemSourceTypeItem",
    "AgentsSearchResponseAgentsItemToolsItemToolType",
    "AgentsSearchResponseAgentsItemUpdatedAt",
    "AgentsSearchResponseAgentsItemUpdatedAtItem",
    "AppAuthScheme",
    "AppAuthSchemeAuthMode",
    "AppModel",
    "AssistantMessage",
    "AssistantMessageContent",
    "AsyncLetta",
    "Audio",
    "AuthRequest",
    "AuthResponse",
    "AuthSchemeField",
    "Block",
    "BlockUpdate",
    "ChatCompletionAssistantMessageParam",
    "ChatCompletionAssistantMessageParamContent",
    "ChatCompletionAssistantMessageParamContentItem",
    "ChatCompletionAudioParam",
    "ChatCompletionAudioParamFormat",
    "ChatCompletionAudioParamVoice",
    "ChatCompletionContentPartImageParam",
    "ChatCompletionContentPartInputAudioParam",
    "ChatCompletionContentPartRefusalParam",
    "ChatCompletionContentPartTextParam",
    "ChatCompletionDeveloperMessageParam",
    "ChatCompletionDeveloperMessageParamContent",
    "ChatCompletionFunctionCallOptionParam",
    "ChatCompletionFunctionMessageParam",
    "ChatCompletionMessageToolCallInput",
    "ChatCompletionMessageToolCallOutput",
    "ChatCompletionMessageToolCallParam",
    "ChatCompletionNamedToolChoiceParam",
    "ChatCompletionPredictionContentParam",
    "ChatCompletionPredictionContentParamContent",
    "ChatCompletionStreamOptionsParam",
    "ChatCompletionSystemMessageParam",
    "ChatCompletionSystemMessageParamContent",
    "ChatCompletionToolMessageParam",
    "ChatCompletionToolMessageParamContent",
    "ChatCompletionToolParam",
    "ChatCompletionUserMessageParam",
    "ChatCompletionUserMessageParamContent",
    "ChatCompletionUserMessageParamContentItem",
    "ChildToolRule",
    "CompletionCreateParamsNonStreaming",
    "CompletionCreateParamsNonStreamingFunctionCall",
    "CompletionCreateParamsNonStreamingMessagesItem",
    "CompletionCreateParamsNonStreamingModalitiesItem",
    "CompletionCreateParamsNonStreamingModel",
    "CompletionCreateParamsNonStreamingReasoningEffort",
    "CompletionCreateParamsNonStreamingResponseFormat",
    "CompletionCreateParamsNonStreamingServiceTier",
    "CompletionCreateParamsNonStreamingStop",
    "CompletionCreateParamsNonStreamingToolChoice",
    "CompletionCreateParamsStreaming",
    "CompletionCreateParamsStreamingFunctionCall",
    "CompletionCreateParamsStreamingMessagesItem",
    "CompletionCreateParamsStreamingModalitiesItem",
    "CompletionCreateParamsStreamingModel",
    "CompletionCreateParamsStreamingReasoningEffort",
    "CompletionCreateParamsStreamingResponseFormat",
    "CompletionCreateParamsStreamingServiceTier",
    "CompletionCreateParamsStreamingStop",
    "CompletionCreateParamsStreamingToolChoice",
    "ConditionalToolRule",
    "ConflictError",
    "ConflictErrorBody",
    "ContextWindowOverview",
    "CreateAgentRequestToolRulesItem",
    "CreateBlock",
    "E2BSandboxConfig",
    "EmbeddingConfig",
    "EmbeddingConfigEmbeddingEndpointType",
    "FileMetadata",
    "FunctionCall",
    "FunctionDefinitionInput",
    "FunctionDefinitionOutput",
    "FunctionOutput",
    "FunctionTool",
    "Health",
    "HttpValidationError",
    "ImageUrl",
    "ImageUrlDetail",
    "InitToolRule",
    "InputAudio",
    "InputAudioFormat",
    "InternalServerError",
    "InternalServerErrorBody",
    "Job",
    "JobStatus",
    "JobType",
    "JsonSchema",
    "Letta",
    "LettaEnvironment",
    "LettaMessageUnion",
    "LettaRequest",
    "LettaRequestConfig",
    "LettaResponse",
    "LettaUsageStatistics",
    "LlmConfig",
    "LlmConfigModelEndpointType",
    "LocalSandboxConfig",
    "Memory",
    "Message",
    "MessageCreate",
    "MessageCreateContent",
    "MessageCreateRole",
    "MessageRole",
    "NotFoundError",
    "NotFoundErrorBody",
    "NotFoundErrorBodyMessage",
    "OpenaiTypesChatChatCompletionMessageToolCallFunction",
    "OpenaiTypesChatChatCompletionMessageToolCallParamFunction",
    "OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction",
    "OpenaiTypesChatCompletionCreateParamsFunction",
    "Organization",
    "OrganizationCreate",
    "Passage",
    "PipRequirement",
    "Provider",
    "ReasoningMessage",
    "ResponseFormatJsonObject",
    "ResponseFormatJsonSchema",
    "ResponseFormatText",
    "Run",
    "SandboxConfig",
    "SandboxConfigCreate",
    "SandboxConfigCreateConfig",
    "SandboxConfigUpdate",
    "SandboxConfigUpdateConfig",
    "SandboxEnvironmentVariable",
    "SandboxEnvironmentVariableCreate",
    "SandboxEnvironmentVariableUpdate",
    "SandboxType",
    "Source",
    "Step",
    "SystemMessage",
    "SystemMessageContent",
    "TemplatesCreateAgentsFromTemplateResponse",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabelItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemNameItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryPromptTemplate",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildren",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildrenType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildrenType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOneType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOne",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOneType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwo",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwoType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCodeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAtItem",
    "TerminalToolRule",
    "TextContent",
    "Tool",
    "ToolCall",
    "ToolCallDelta",
    "ToolCallMessage",
    "ToolCallMessageToolCall",
    "ToolCreate",
    "ToolReturnMessage",
    "ToolReturnMessageStatus",
    "ToolType",
    "UnprocessableEntityError",
    "UpdateAgentToolRulesItem",
    "UsageStatistics",
    "User",
    "UserCreate",
    "UserMessage",
    "UserMessageContent",
    "UserUpdate",
    "ValidationError",
    "ValidationErrorLocItem",
    "__version__",
    "agents",
    "blocks",
    "health",
    "jobs",
    "models",
    "providers",
    "runs",
    "sources",
    "steps",
    "tag",
    "templates",
    "tools",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .templates_create_agents_from_template_response_agents_item_llm_config_model_endpoint_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType,
)
import typing
from .templates_create_agents_from_template_response_agents_item_llm_config_model_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_model_wrapper import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_put_inner_thoughts_in_kwargs import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_handle import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_temperature import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig(UncheckedBaseModel):
    model: str
    model_endpoint_type: TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType
    model_endpoint: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint] = None
    model_wrapper: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper] = None
    context_window: float
    put_inner_thoughts_in_kwargs: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs
    ] = None
    handle: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle] = None
    temperature: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tools_item_source_code_item import (
    AgentsSearchResponseAgentsItemToolsItemSourceCodeItem,
)

AgentsSearchResponseAgentsItemToolsItemSourceCode = typing.Union[
    str, typing.Optional[str], typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolsItemSourceCodeItem]]
]
